pub struct ConcurrentStateRegistry<K, N> { /* private fields */ }Implementations
Sourceimpl<K, N, D, S, C> ConcurrentStateRegistry<K, N>
impl<K, N, D, S, C> ConcurrentStateRegistry<K, N>
pub fn with_capacity_and_shard_amount( capacity: usize, shard_amount: usize, ) -> ConcurrentStateRegistry<K, N>
Sourcepub fn insert_if_not_dominated(
&self,
dp: &D,
node: N,
) -> ConcurrentInsertionResult<N>
pub fn insert_if_not_dominated( &self, dp: &D, node: N, ) -> ConcurrentInsertionResult<N>
Inserts a node into the registry if it is not dominated by any other node.
Sourcepub fn insert_with_if_not_dominated(
&self,
dp: &mut D,
state: S,
cost: C,
constructor: impl FnOnce(&mut D, S, C, Option<&N>) -> Option<N>,
) -> ConcurrentInsertionResult<N>
pub fn insert_with_if_not_dominated( &self, dp: &mut D, state: S, cost: C, constructor: impl FnOnce(&mut D, S, C, Option<&N>) -> Option<N>, ) -> ConcurrentInsertionResult<N>
Inserts a node created from a state and a cost by a constructor into the registry if it is not dominated by any other node.
The constructor may use the information of a node that has the same state as the new node.
If the constructor returns None, the node is not inserted.
pub fn clear(&mut self)