SendableCostNode

pub struct SendableCostNode<D, S, C, L> { /* private fields */ }
Node ordered by the cost.

Implementations

Source

impl<D, S, C, L> SendableCostNode<D, S, C, L>
where D: DpMut<State = S, CostType = C>, C: Neg<Output = C>, L: Copy + Default,

pub fn create_root(dp: &D, state: S, cost: C) -> Self

Creates a new root node given the state and the cost.

pub fn create_child(&self, dp: &D, state: S, cost: C, transition: L) -> Self

Creates a new child node given the state, the cost, and the transition.