pub struct SendableCostNode<D, S, C, L> { /* private fields */ }Expand description
Node ordered by the cost.
Implementations
Sourceimpl<D, S, C, L> SendableCostNode<D, S, C, L>
impl<D, S, C, L> SendableCostNode<D, S, C, L>
Sourcepub fn create_root(dp: &D, state: S, cost: C) -> Self
pub fn create_root(dp: &D, state: S, cost: C) -> Self
Creates a new root node given the state and the cost.
Sourcepub fn create_child(&self, dp: &D, state: S, cost: C, transition: L) -> Self
pub fn create_child(&self, dp: &D, state: S, cost: C, transition: L) -> Self
Creates a new child node given the state, the cost, and the transition.